@@ -51,6 +51,7 @@
 #include "segatex_yum.h"
 #include "segatex_yum_process.h"
 #include "segatex_audit2allow.h"
+#include "segatex_core.h"
 #include "mainwindow.h"
 
 MainWindow::MainWindow(QWidget *parent, const char *name)
@@ -81,6 +82,7 @@ MainWindow::MainWindow(QWidget *parent, const char *name)
 	segatex_apply = 0;
 	selinux_yum = 0;
 	selinux_audit2allow = 0;
+	segatex_core_o = 0;
 
 	//connect SIGNAL to objects    
 
@@ -96,7 +98,7 @@ MainWindow::MainWindow(QWidget *parent, const char *name)
 	createToolBars();
 	createStatusBar();
 
-	setCaption(tr("segatex_suite-1.4"));
+	setCaption(tr("segatex_suite-1.6"));
 	setIcon(QPixmap::fromMimeSource("icon.png"));
 }
 
@@ -380,6 +382,11 @@ void MainWindow::createActions()
 	audit2allowAct->setStatusTip(tr("audit2allow"));
 	connect(audit2allowAct, SIGNAL(activated()), this, SLOT(audit2allow()));
 	connect(audit2allowAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
+
+	segatex_coreAct = new QAction(tr("Analize audit.&log"), 0, this);
+	segatex_coreAct->setStatusTip(tr("Analize audit.log in many ways."));
+	connect(segatex_coreAct, SIGNAL(activated()), this, SLOT(segatex_core()));
+	connect(segatex_coreAct, SIGNAL(activated()), this, SLOT(updateSegatexStateIndicator()));
 }
 
 void MainWindow::createMenus()
@@ -442,6 +449,7 @@ void MainWindow::createMenus()
 	//newly added
 	policyMenu = new QPopupMenu(this);
 
+	segatex_coreAct->addTo(policyMenu);
 	audit2allowAct->addTo(policyMenu);
 	selinuxYumAct->addTo(policyMenu);
 	enforcingAct->addTo(policyMenu);
@@ -795,22 +803,23 @@ void MainWindow::notice()
 
 void MainWindow::about()
 {
-    QMessageBox::about(this, tr("About segatex_suite"),
-            tr("<h2>segatex_suite-1.4</h2>"
-               "<p>Copyright &copy; 2007 Shintaro Fujiwara."
-               "<p>segatex_suite is a SELinux tool"
-               "<b>written with Qt</b>."));
+	QMessageBox::about(this, tr("About segatex_suite"),
+		tr("<h2>segatex_suite-1.6</h2>"
+		"<p>Copyright &copy; 2007"
+		"<p>Shintaro Fujiwara."
+		"<p>segatex_suite is a SELinux tool"
+		"<p><b>written with Qt</b>."));
 }
 //newly added
 void MainWindow::howtouse()
 {
-    QMessageBox::about(this, tr("How to use"),
-	    tr("<h2>How to use segatex_suite</h2>"
+	QMessageBox::about(this, tr("How to use"),
+		tr("<h2>How to use segatex_suite</h2>"
 		"<p><font color=\"blue\">[segatex]</font>"
 		"<p>You can set selinux enforcing"
 		" and permissive just pushing button."
 		" You can install/update SELinux related"
-		" RPMs."
+		" RPMs.You can audit2allow -m local -a."
 		"<p><font color=\"blue\">[segatex_editor]</font>"
 		"<p>Push Parselines,Selpaw,Refine"
 		" one by one orderly."
@@ -942,3 +951,12 @@ void MainWindow::audit2allow()
 	selinux_audit2allow->raise();
 	selinux_audit2allow->setActiveWindow();
 }
+void MainWindow::segatex_core()
+{
+	if(!segatex_core_o) {
+		segatex_core_o = new SegatexCore(this);
+	}
+	segatex_core_o->show();
+	segatex_core_o->raise();
+	segatex_core_o->setActiveWindow();
+}
