@@ -91,6 +91,14 @@ protected:
 	QString line_started;
 	QString line_ended;
 	QString line_analized;//every lines put in this var
+	QString line_analized_if_clause;
+	QString line_analized_dollar_one;
+	QString line_analized_dollar_two;
+	QString line_analized_dollar_three;
+	QString line_analized_dollar_four;
+	QString line_analized_dollar_five;
+	QString line_analized_dollar_six;
+	QString line_analized_interface_name;
 	QString line_interface;
 	QString line_added;
 	QString double_quote;
@@ -106,10 +114,15 @@ protected:
 	QString var1;
 	QString var2;
 	QString var3;
+	QString var4;
+	QString var5;
+	QString var6;
 	QString first_var;
 	QString second_var;
 	QString third_var;
 	QString fourth_var;
+	QString fifth_var;
+	QString sixth_var;
 	QString tab;
 	QString layer_name,interface_name_this;
 	QString interface_summary_this;
